@@ -143,6 +143,26 @@ class InvoicingVault(InvoicingMixin):
             else:
                 yield {}, certification_data, original_chain
 
+    def cancel(self, gid, rfc):
+        # Validate data
+        self.validate_rfc(rfc)
+
+        # Get rfc_id, key_id and certificate_num
+        try:
+            self._get_signature_data(rfc)
+        except ResourceNotFound:
+            raise InvalidRFCId("rfc {} does not have a private key saved in the vault".format(rfc))
+
+        # Get certificate
+        self._get_certificate()
+
+        data = {
+            'rfc_id': self.rfc_id,
+            'key_id': self.key_id,
+            'message': base64.b64encode(self.cert_der).decode("utf-8")
+        }
+        return self.make_request(method="POST", json=data, path="/invoicing/cancel_using_vault_private_key/invoice/{}/".format(gid)).json()
+
 class Invoicing(InvoicingMixin):
     """Invoicing class
     Args:
